# hey-bob

A python package that serves as the perfect companion when you need to find extra inspiration, delivering random Bob Dylan song lyrics whenever you need them right at your CLI.

Install it by typing:
```bash
pip install hey-bob
```

Then, any time you need Bob´s wise words just type in your terminal
```bash
hey-bob
```